@@ -145,16 +145,19 @@ class FNN(PyTorchModel):
         self.eval()
 
         if isinstance(x, torch.Tensor):
-            _x = x.unsqueeze(0)
+            # Predict target value for single input data.
+            with torch.no_grad():
+                if is_gpu_runnable():
+                    return self(torch.stack([x, x]).cuda()).cpu()[0].view(1, -1)
+                else:
+                    return self(torch.stack([x, x])).cpu()[0].view(1, -1)
         else:
-            _x = x.x
-
-        # Predict the target values for the given dataset.
-        with torch.no_grad():
-            if is_gpu_runnable():
-                return self(_x.cuda()).cpu()
-            else:
-                return self(_x).cpu()
+            # Predict target values for a set of input data.
+            with torch.no_grad():
+                if is_gpu_runnable():
+                    return self(x.x.cuda()).cpu()
+                else:
+                    return self(x.x).cpu()
 
 
 class FCNN(FNN):
